# Retsu

Retsu aims to wrap-up Celery in way to facilitate to create parallel and serial
tasks

- Software License: BSD 3 Clause
- Documentation: https://osl-incubator.github.io/retsu

## Features

TBD

## Credits

This package was created with
[scicookie](https://github.com/osl-incubator/scicookie) project template.
